@@ -4,47 +4,10 @@ use strict;
 
 use Rose::HTML::Object::Errors qw(:number);
 
-use Rose::HTML::Form::Field::Text;
-our @ISA = qw(Rose::HTML::Form::Field::Text);
+use Rose::HTML::Form::Field::Numeric;
+our @ISA = qw(Rose::HTML::Form::Field::Numeric);
 
-our $VERSION = '0.545';
-
-use Rose::Object::MakeMethods::Generic
-(
-  scalar => [ qw(min max) ],
-);
-
-__PACKAGE__->default_html_attr_value(size  => 6);
-
-sub positive
-{
-  my($self) = shift;
-
-  if(!@_ || $_[0])
-  {
-    $self->min(0);
-    $self->max(undef);
-  }
-  elsif(@_)
-  {
-    $self->min(undef);
-  }
-}
-
-sub negative
-{
-  my($self) = shift;
-
-  if(!@_ || $_[0])
-  {
-    $self->max(0);
-    $self->min(undef);
-  }
-  elsif(@_)
-  {
-    $self->max(undef);
-  }
-}
+our $VERSION = '0.549';
 
 sub validate
 {
@@ -54,49 +17,52 @@ sub validate
   return $ok  unless($ok);
 
   my $value = $self->internal_value;
-  return 1  unless(length $value);
+  return 1  unless(defined $value && length $value);
 
-  my $min = $self->min;
-  my $max = $self->max;
-
-  my $name = sub { $self->label || $self->name };
+  my $name = sub { $self->error_label || $self->name };
 
   unless($value =~ /^-?\d+$/)
   {
-    if(defined $min && $min >= 0)
-    {
-      $self->add_error_id(NUM_INVALID_INTEGER_POSITIVE, { label => $name })
-    }
-    else
-    {
-      $self->add_error_id(NUM_INVALID_INTEGER, { label => $name })
-    }
-
-    return 0;
-  }
-
-  if(defined $min && $value < $min)
-  {
-    if($min == 0)
-    {
-      $self->add_error_id(NUM_NOT_POSITIVE_INTEGER, { label => $name });
-    }
-    else
-    {
-      $self->add_error_id(NUM_BELOW_MIN, { label => $name, value => ($min - 1) });
-    }
-    return 0;
-  }
-
-  if(defined $max && $value > $max)
-  {
-    $self->add_error_id(NUM_ABOVE_MAX, { label => $name, value => $max });
+    $self->add_error_id(NUM_INVALID_INTEGER, { label => $name });
     return 0;
   }
 
   return 1;
 }
 
+my %Error_Map =
+(
+  NUM_INVALID_NUMBER()          => NUM_INVALID_INTEGER,
+  NUM_INVALID_NUMBER_POSITIVE() => NUM_INVALID_INTEGER_POSITIVE,
+  NUM_NOT_POSITIVE_NUMBER()     => NUM_NOT_POSITIVE_INTEGER,
+);
+
+sub add_error_id
+{
+  my($self) = shift;
+  my $error_id = shift;
+  my $new_error_id = $Error_Map{$error_id} || $error_id;
+  return $self->SUPER::add_error_id($new_error_id, @_);
+}
+
+sub error_id
+{
+  my($self) = shift;
+
+  if(@_)
+  {
+    my $error_id = shift;
+    my $new_error_id = $Error_Map{$error_id} || $error_id;
+    return $self->SUPER::error_id($new_error_id);
+  }
+  else
+  {
+    my $error_id = $self->SUPER::error_id;
+    my $new_error_id = $Error_Map{$error_id} || $error_id;
+    return $new_error_id;
+  }
+}
+
 if(__PACKAGE__->localizer->auto_load_messages)
 {
   __PACKAGE__->localizer->load_all_messages;
@@ -111,24 +77,24 @@ __DATA__
 NUM_INVALID_INTEGER          = "[label] must be an integer."
 NUM_INVALID_INTEGER_POSITIVE = "[label] must be a positive integer."
 NUM_NOT_POSITIVE_INTEGER     = "[label] must be a positive integer."
-NUM_BELOW_MIN                = "[label] must be greater than [value]."
-NUM_ABOVE_MAX                = "[label] must be less than or equal to [value]."
 
 [% LOCALE de %]
 
 NUM_INVALID_INTEGER          = "[label] muß eine Ganzzahl sein."
 NUM_INVALID_INTEGER_POSITIVE = "[label] muß eine positive Ganzzahl sein."
 NUM_NOT_POSITIVE_INTEGER     = "[label] muß eine positive Ganzzahl sein."
-NUM_BELOW_MIN                = "[label] muß größer als [value] sein."
-NUM_ABOVE_MAX                = "[label] muß kleiner oder gleich [value] sein."
 
 [% LOCALE fr %]
 
 NUM_INVALID_INTEGER          = "[label] doit être un entier."
 NUM_INVALID_INTEGER_POSITIVE = "[label] doit être un entier positif."
 NUM_NOT_POSITIVE_INTEGER     = "[label] doit être un entier positif."
-NUM_BELOW_MIN                = "[label] doit être plus grand que [value]."
-NUM_ABOVE_MAX                = "[label] doit être plus petit ou égal à [value]."
+
+[% LOCALE bg %]
+
+NUM_INVALID_INTEGER          = "Полето '[label]' трябва да бъде цяло число."
+NUM_INVALID_INTEGER_POSITIVE = "Полето '[label]' трябва да бъде цяло положително число."
+NUM_NOT_POSITIVE_INTEGER     = "Полето '[label]' трябва да бъде цяло положително число."
 
 __END__
 
@@ -168,7 +134,7 @@ Rose::HTML::Form::Field::Integer - Text field that only accepts integer values.
 
 =head1 DESCRIPTION
 
-L<Rose::HTML::Form::Field::Integer> is a subclass of L<Rose::HTML::Form::Field::Text> only accepts integer values.  It overrides the L<validate()|Rose::HTML::Form::Field/validate> method of its parent class, returning true if the L<internal_value()|Rose::HTML::Form::Field/internal_value> is a valid integer, or setting an error message and returning false otherwise.
+L<Rose::HTML::Form::Field::Integer> is a subclass of L<Rose::HTML::Form::Field::Numeric> that only accepts integer values.  It overrides the L<validate()|Rose::HTML::Form::Field/validate> method of its parent class, returning true if the L<internal_value()|Rose::HTML::Form::Field/internal_value> is a valid integer, or setting an error message and returning false otherwise.
 
 Use the L<min|/min> and :<max|/max> attributes to control whether the range of valid values.
 
@@ -196,7 +162,7 @@ If BOOL is true or omitted, sets L<min|/min> to C<0>.  If BOOL is false, sets L<
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
