@@ -7,7 +7,7 @@ use Carp();
 use Rose::HTML::Form::Field::Option::Container;
 our @ISA = qw(Rose::HTML::Form::Field::Option::Container);
 
-our $VERSION = '0.548';
+our $VERSION = '0.551';
 
 __PACKAGE__->add_required_html_attrs(
 {
@@ -263,10 +263,30 @@ Add multiple values to the list of selected values.
 
 This is an alias for the L<options|/options> method.
 
+=item B<delete_option VALUE>
+
+Deletes the first option (according to the order that they are returned from L<options()|/options>) whose "value" HTML attribute is VALUE.  Returns the deleted option or undef if no such option exists.
+
+=item B<delete_options LIST>
+
+Repeatedly calls L<delete_option|/delete_option>, passing each value in LIST as an arugment.
+
+=item B<delete_option_group LABEL>
+
+Deletes the first option group (according to the order that they are returned from L<options()|/options>) whose "label" HTML attribute is LABEL.  Returns the deleted option group or undef if no such option exists.
+
+=item B<delete_option_groups LIST>
+
+Repeatedly calls L<delete_option_group|/delete_option_group>, passing each value in LIST.
+
 =item B<has_value VALUE>
 
 Returns true if VALUE is selected in the select box, false otherwise.
 
+=item B<hide_all_options>
+
+Set L<hidden|Rose::HTML::Form::Field::Option/hidden> to true for all L<options|/options>.
+
 =item B<internal_value>
 
 If L<multiple|/multiple> is true, a reference to an array of selected values is returned in scalar context, and a list of selected values is returned in list context.  Otherwise, the selected value is returned (or undef if no value is selected).
@@ -299,7 +319,15 @@ To set an ordered list of option values along with labels in the constructor, us
 
 Remember that methods are called in the order that they appear in the constructor arguments (see the L<Rose::Object> documentation), so L<options()|/options> will be called before L<labels()|/labels> in the example above.  This is important; it will not work in the opposite order.
 
-Returns a list of the select box's L<Rose::HTML::Form::Field::Option> and/or L<Rose::HTML::Form::Field::OptionGroup> objects in list context, or a reference to an array of the same in scalar context. These are the actual objects used in the field. Modifying them will modify the field itself.
+Returns a list of the select box's L<Rose::HTML::Form::Field::Option> and/or L<Rose::HTML::Form::Field::OptionGroup> objects in list context, or a reference to an array of the same in scalar context. L<Hidden|Rose::HTML::Form::Field::Option/hidden> options I<will> be included in this list.  These are the actual objects used in the field. Modifying them will modify the field itself.
+
+=item B<option_group LABEL>
+
+Returns the L<Rose::HTML::Form::Field::OptionGroup> object whose "label" HTML attribute is LABEL, or undef if no such option group exists.
+
+=item B<show_all_options>
+
+Set L<hidden|Rose::HTML::Form::Field::Option/hidden> to false for all L<options|/options>.
 
 =item B<value [VALUE]>
 
