@@ -205,7 +205,7 @@ Simply calls L<contents()|/contents>, passing all arguments.
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
